==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Points/Gui/Resources/translations/Points_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="eu" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="188"/>
      <source>Points</source>
      <translation>Puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="189"/>
      <source>Convert to points...</source>
      <translation>Bihurtu puntuetara...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="190"/>
      <location filename="../../Command.cpp" line="192"/>
      <source>Convert to points</source>
      <translation>Bihurtu puntuetara</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location filename="../../Command.cpp" line="112"/>
      <source>Points</source>
      <translation>Puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="113"/>
      <source>Export points...</source>
      <translation>Esportatu puntuak...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="114"/>
      <location filename="../../Command.cpp" line="116"/>
      <source>Exports a point cloud</source>
      <translation>Esportatu puntuen hodei bat</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location filename="../../Command.cpp" line="65"/>
      <source>Points</source>
      <translation>Puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="66"/>
      <source>Import points...</source>
      <translation>Inportatu puntuak...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="67"/>
      <location filename="../../Command.cpp" line="69"/>
      <source>Imports a point cloud</source>
      <translation>Inportatu puntuen hodei bat</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location filename="../../Command.cpp" line="318"/>
      <source>Points</source>
      <translation>Puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="319"/>
      <source>Merge point clouds</source>
      <translation>Fusionatu puntuen hodeiak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="320"/>
      <location filename="../../Command.cpp" line="322"/>
      <source>Merge several point clouds into one</source>
      <translation>Fusionatu puntuen hainbat hodei bakarrean</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location filename="../../Command.cpp" line="273"/>
      <source>Points</source>
      <translation>Puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="274"/>
      <source>Cut point cloud</source>
      <translation>Moztu puntuen hodeia</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="275"/>
      <location filename="../../Command.cpp" line="277"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Puntuen hodei bat mozten du hautatutako poligono batekin</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location filename="../../Command.cpp" line="151"/>
      <source>Points</source>
      <translation>Puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="152"/>
      <source>Transform Points</source>
      <translation>Transformatu puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="153"/>
      <location filename="../../Command.cpp" line="155"/>
      <source>Test to transform a point cloud</source>
      <translation>Puntuen hodei bat transformatzeko proba</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="14"/>
      <source>ASCII points import</source>
      <translation>ASCII puntuen inportazioa</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="34"/>
      <source>Template:</source>
      <translation>Txantiloia:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="46"/>
      <source>Special lines</source>
      <translation>Lerro bereziak</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="72"/>
      <source>Ignore lines starting with:</source>
      <translation>Ez ikusi honekin hasten diren lerroak:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="79"/>
      <source>Cluster by lines starting with:</source>
      <translation>Multzokatu honekin hasten diren lerroen arabera:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="88"/>
      <source>First line:</source>
      <translation>Lehen lerroa:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="100"/>
      <source>Ignore</source>
      <translation>Ezikusi</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="110"/>
      <source>Number of points</source>
      <translation>Puntu kopurua</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="126"/>
      <source>Point format</source>
      <translation>Puntu-formatua</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="147"/>
      <location filename="../../DlgPointsRead.ui" line="176"/>
      <location filename="../../DlgPointsRead.ui" line="233"/>
      <source>none</source>
      <translation>bat ere ez</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="152"/>
      <location filename="../../DlgPointsRead.ui" line="181"/>
      <location filename="../../DlgPointsRead.ui" line="238"/>
      <source>I,J,K (normal vector)</source>
      <translation>I,J,K (bektore normala)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="157"/>
      <location filename="../../DlgPointsRead.ui" line="186"/>
      <location filename="../../DlgPointsRead.ui" line="243"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I,K (2Dko bektore normala)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="162"/>
      <location filename="../../DlgPointsRead.ui" line="191"/>
      <location filename="../../DlgPointsRead.ui" line="248"/>
      <source>R,G,B (color)</source>
      <translation>R,G,B (kolorea)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="167"/>
      <location filename="../../DlgPointsRead.ui" line="196"/>
      <location filename="../../DlgPointsRead.ui" line="253"/>
      <source>I (Gray value)</source>
      <translation>I (gris-balioa)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="204"/>
      <source>Number separator:</source>
      <translation>Zenbaki-banatzailea:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="211"/>
      <location filename="../../DlgPointsRead.ui" line="218"/>
      <location filename="../../DlgPointsRead.ui" line="225"/>
      <source>Next block:</source>
      <translation>Hurrengo blokea:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="265"/>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="270"/>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="275"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="280"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="289"/>
      <source>X,Y,Z</source>
      <translation>X,Y,Z</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="294"/>
      <source>X,Y</source>
      <translation>X,Y</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="302"/>
      <source>Points format:</source>
      <translation>Puntuen formatua:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="314"/>
      <source>Preview</source>
      <translation>Aurrebista</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="341"/>
      <source>Number of previewed lines:</source>
      <translation>Aurreikusitako lerro kopurua:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="348"/>
      <source>100</source>
      <translation>100</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="79"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>Point formats</source>
      <translation>Puntu-formatuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="79"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>All Files</source>
      <translation>Fitxategi guztiak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="200"/>
      <source>Distance</source>
      <translation>Distantzia</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="201"/>
      <source>Enter maximum distance:</source>
      <translation>Sartu distantzia maximoa:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>Points tools</source>
      <translation>Puntuen tresna</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="38"/>
      <source>&amp;Points</source>
      <translation>&amp;Puntuak</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Points/Gui/Resources/translations/Points_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="189"/>
      <source>Points</source>
      <translation>Puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="190"/>
      <source>Convert to points...</source>
      <translation>Bihurtu puntuetara...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="191"/>
      <location filename="../../Command.cpp" line="193"/>
      <source>Convert to points</source>
      <translation>Bihurtu puntuetara</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location filename="../../Command.cpp" line="112"/>
      <source>Points</source>
      <translation>Puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="113"/>
      <source>Export points...</source>
      <translation>Esportatu puntuak...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="114"/>
      <location filename="../../Command.cpp" line="116"/>
      <source>Exports a point cloud</source>
      <translation>Esportatu puntuen hodei bat</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location filename="../../Command.cpp" line="67"/>
      <source>Points</source>
      <translation>Puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="68"/>
      <source>Import points...</source>
      <translation>Inportatu puntuak...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="69"/>
      <location filename="../../Command.cpp" line="71"/>
      <source>Imports a point cloud</source>
      <translation>Inportatu puntuen hodei bat</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location filename="../../Command.cpp" line="320"/>
      <source>Points</source>
      <translation>Puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="321"/>
      <source>Merge point clouds</source>
      <translation>Fusionatu puntuen hodeiak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="322"/>
      <location filename="../../Command.cpp" line="324"/>
      <source>Merge several point clouds into one</source>
      <translation>Fusionatu puntuen hainbat hodei bakarrean</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location filename="../../Command.cpp" line="275"/>
      <source>Points</source>
      <translation>Puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="276"/>
      <source>Cut point cloud</source>
      <translation>Moztu puntuen hodeia</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="277"/>
      <location filename="../../Command.cpp" line="279"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Puntuen hodei bat mozten du hautatutako poligono batekin</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsStructure</name>
    <message>
      <location filename="../../Command.cpp" line="363"/>
      <source>Points</source>
      <translation>Puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="364"/>
      <source>Structured point cloud</source>
      <translation>Puntu-hodei egituratua</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="365"/>
      <location filename="../../Command.cpp" line="367"/>
      <source>Convert points to structured point cloud</source>
      <translation>Bihurtu puntuak puntu-hodei egituratu</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location filename="../../Command.cpp" line="152"/>
      <source>Points</source>
      <translation>Puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="153"/>
      <source>Transform Points</source>
      <translation>Transformatu puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="154"/>
      <location filename="../../Command.cpp" line="156"/>
      <source>Test to transform a point cloud</source>
      <translation>Puntuen hodei bat transformatzeko proba</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="88"/>
      <source>Import points</source>
      <translation>Inportatu puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="168"/>
      <source>Transform points</source>
      <translation>Transformatu puntuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="208"/>
      <source>Convert to points</source>
      <translation>Bihurtu puntuetara</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="468"/>
      <location filename="../../ViewProvider.cpp" line="627"/>
      <source>Cut points</source>
      <translation>Moztu puntuak</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="14"/>
      <source>ASCII points import</source>
      <translation>ASCII puntuen inportazioa</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="34"/>
      <source>Template:</source>
      <translation>Txantiloia:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="46"/>
      <source>Special lines</source>
      <translation>Lerro bereziak</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="72"/>
      <source>Ignore lines starting with:</source>
      <translation>Ez ikusi honekin hasten diren lerroak:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="79"/>
      <source>Cluster by lines starting with:</source>
      <translation>Multzokatu honekin hasten diren lerroen arabera:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="88"/>
      <source>First line:</source>
      <translation>Lehen lerroa:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="100"/>
      <source>Ignore</source>
      <translation>Ezikusi</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="110"/>
      <source>Number of points</source>
      <translation>Puntu kopurua</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="126"/>
      <source>Point format</source>
      <translation>Puntu-formatua</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="147"/>
      <location filename="../../DlgPointsRead.ui" line="176"/>
      <location filename="../../DlgPointsRead.ui" line="233"/>
      <source>none</source>
      <translation>bat ere ez</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="152"/>
      <location filename="../../DlgPointsRead.ui" line="181"/>
      <location filename="../../DlgPointsRead.ui" line="238"/>
      <source>I,J,K (normal vector)</source>
      <translation>I,J,K (bektore normala)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="157"/>
      <location filename="../../DlgPointsRead.ui" line="186"/>
      <location filename="../../DlgPointsRead.ui" line="243"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I,K (2Dko bektore normala)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="162"/>
      <location filename="../../DlgPointsRead.ui" line="191"/>
      <location filename="../../DlgPointsRead.ui" line="248"/>
      <source>R,G,B (color)</source>
      <translation>R,G,B (kolorea)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="167"/>
      <location filename="../../DlgPointsRead.ui" line="196"/>
      <location filename="../../DlgPointsRead.ui" line="253"/>
      <source>I (Gray value)</source>
      <translation>I (gris-balioa)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="204"/>
      <source>Number separator:</source>
      <translation>Zenbaki-banatzailea:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="211"/>
      <location filename="../../DlgPointsRead.ui" line="218"/>
      <location filename="../../DlgPointsRead.ui" line="225"/>
      <source>Next block:</source>
      <translation>Hurrengo blokea:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="265"/>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="270"/>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="275"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="280"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="289"/>
      <source>X,Y,Z</source>
      <translation>X,Y,Z</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="294"/>
      <source>X,Y</source>
      <translation>X,Y</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="302"/>
      <source>Points format:</source>
      <translation>Puntuen formatua:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="314"/>
      <source>Preview</source>
      <translation>Aurrebista</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="341"/>
      <source>Number of previewed lines:</source>
      <translation>Aurreikusitako lerro kopurua:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="348"/>
      <source>100</source>
      <translation>100</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="81"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>Point formats</source>
      <translation>Puntu-formatuak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="81"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>All Files</source>
      <translation>Fitxategi guztiak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="202"/>
      <source>Distance</source>
      <translation>Distantzia</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="203"/>
      <source>Enter maximum distance:</source>
      <translation>Sartu distantzia maximoa:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>Points tools</source>
      <translation>Puntuen tresna</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="38"/>
      <source>&amp;Points</source>
      <translation>&amp;Puntuak</translation>
    </message>
  </context>
</TS>
